pub enum CommentType {
SingleLine,
MultiLine,
}Expand description
Comment type markers for single-line (//) and multi-line (/* */) comments.
Variants
Implementations
Sourceimpl CommentType
impl CommentType
Sourcepub fn into_owned(self) -> CommentType
pub fn into_owned(self) -> CommentType
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.