pub enum ExtendEntry<'a> {
Comment(Comment<'a>),
Field(Field<'a>),
}Expand description
Entries that can appear inside an extend block.
Variants
Implementations
Sourceimpl ExtendEntry<'_>
impl ExtendEntry<'_>
Sourcepub fn into_owned(self) -> ExtendEntry<'static>
pub fn into_owned(self) -> ExtendEntry<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.