pub enum FieldModifier {
Optional,
Required,
Repeated,
}Expand description
Field modifier keywords.
Variants
Implementations
Sourceimpl FieldModifier
impl FieldModifier
Sourcepub fn into_owned(self) -> FieldModifier
pub fn into_owned(self) -> FieldModifier
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.