MessageEntry

Enum MessageEntry 

pub enum MessageEntry<'a> {
    Comment(Comment<'a>),
    Option(Option<'a>),
    Field(Field<'a>),
    OneOf(OneOf<'a>),
    Message(Message<'a>),
    Extend(Extend<'a>),
    Enum(Enum<'a>),
    ReservedIndices(ReservedIndices),
    ReservedIdents(ReservedIdents<'a>),
    Extensions(Extensions),
}
Entries that can appear inside a message block.

Variants



Comment(Comment<'a>)



Option(Option<'a>)



Field(Field<'a>)



OneOf(OneOf<'a>)



Message(Message<'a>)



Extend(Extend<'a>)



Enum(Enum<'a>)



ReservedIndices(ReservedIndices)



ReservedIdents(ReservedIdents<'a>)



Extensions(Extensions)

Implementations

Source

impl MessageEntry<'_>

pub fn into_owned(self) -> MessageEntry<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.