pub enum OneOfEntry<'a> {
Comment(Comment<'a>),
Option(Option<'a>),
Field(Field<'a>),
}Expand description
Entries that can appear inside a oneof block.
Variants
Implementations
Sourceimpl OneOfEntry<'_>
impl OneOfEntry<'_>
Sourcepub fn into_owned(self) -> OneOfEntry<'static>
pub fn into_owned(self) -> OneOfEntry<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.