RootEntry

Enum RootEntry 

pub enum RootEntry<'a> {
    Comment(Comment<'a>),
    Syntax(Cow<'a, str>),
    Package(Cow<'a, str>),
    Import(Cow<'a, str>),
    Option(Option<'a>),
    Service(Service<'a>),
    Message(Message<'a>),
    Extend(Extend<'a>),
    Enum(Enum<'a>),
}
Top-level entries in a .proto file.

Examples

use protobuf_ast_parser::ast::{RootEntry, Comment};

let entry = RootEntry::from(Comment::single_line("// hi"));

Variants



Comment(Comment<'a>)



Syntax(Cow<'a, str>)



Package(Cow<'a, str>)



Import(Cow<'a, str>)



Option(Option<'a>)



Service(Service<'a>)



Message(Message<'a>)



Extend(Extend<'a>)



Enum(Enum<'a>)

Implementations

Source

impl RootEntry<'_>

pub fn into_owned(self) -> RootEntry<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.