pub enum ServiceEntry<'a> {
Comment(Comment<'a>),
Option(Option<'a>),
Rpc(Rpc<'a>),
}Expand description
Entries that can appear inside a service block.
Variants
Implementations
Sourceimpl ServiceEntry<'_>
impl ServiceEntry<'_>
Sourcepub fn into_owned(self) -> ServiceEntry<'static>
pub fn into_owned(self) -> ServiceEntry<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.