pub struct EnumVariant<'a> {
pub ident: Cow<'a, str>,
pub value: i64,
pub options: Vec<Option<'a>>,
}Expand description
Enum variant definition inside an enum block.
Examples
use protobuf_ast_parser::ast::EnumVariant;
let variant = EnumVariant::new("FIRST", 1, vec![]);
assert_eq!(variant.value, 1);Fields
ident: Cow<'a, str>value: i64options: Vec<Option<'a>>Implementations
Sourceimpl EnumVariant<'_>
impl EnumVariant<'_>
Sourcepub fn into_owned(self) -> EnumVariant<'static>
pub fn into_owned(self) -> EnumVariant<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.