Field

Struct Field 

pub struct Field<'a> {
    pub modifier: Option<FieldModifier>,
    pub type: Cow<'a, str>,
    pub ident: Cow<'a, str>,
    pub index: i64,
    pub options: Vec<Option<'a>>,
}
Field definition inside a message, oneof, or extend block.

Examples

use protobuf_ast_parser::ast::{Field, FieldModifier};

let field = Field::new(Some(FieldModifier::Optional), "string", "name", 1, vec![]);
assert_eq!(field.index, 1);

Fields

modifier: Option<FieldModifier>type: Cow<'a, str>ident: Cow<'a, str>index: i64options: Vec<Option<'a>>

Implementations

Source

impl Field<'_>

pub fn into_owned(self) -> Field<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl<'a> Field<'a>

pub fn new( modifier: Option<FieldModifier>, type: &'a str, ident: &'a str, index: i64, options: Vec<Option<'a>>, ) -> Self