Option

Struct Option 

pub struct Option<'a> {
    pub key: Cow<'a, str>,
    pub value: MapValue<'a>,
}
Represents an option statement or an inline option list entry.

Examples

use protobuf_ast_parser::ast::{MapValue, Option};

let option = Option::new("deprecated", MapValue::from(true));
assert_eq!(option.key, "deprecated");

Fields

key: Cow<'a, str>value: MapValue<'a>

Implementations

Source

impl Option<'_>

pub fn into_owned(self) -> Option<'static>

Copy the structure and clone the original values if it’s not owned.

This is always a deep copy of the structure.

Source

impl<'a> Option<'a>

pub fn new(key: &'a str, value: MapValue<'a>) -> Self