Token

Enum Token 

pub enum Token<'a> {
Show 39 variants SingleLineComment(&'a str), MultiLineComment(&'a str), Eq, Colon, Semicolon, Comma, Period, OpenPth, ClosePth, OpenBracket, CloseBracket, OpenBrace, CloseBrace, OpenAngle, CloseAngle, Boolean(bool), Integer(i64), To, Max, Syntax, Option, Package, Import, Service, Rpc, Stream, Returns, Message, OneOf, Extend, Enum, Reserved, Extensions, Optional, Required, Repeated, Map, String(&'a str), Ident(&'a str),
}
Token kinds produced by the lexer.

Variants



SingleLineComment(&'a str)



MultiLineComment(&'a str)



Eq



Colon



Semicolon



Comma



Period



OpenPth



ClosePth



OpenBracket



CloseBracket



OpenBrace



CloseBrace



OpenAngle



CloseAngle



Boolean(bool)



Integer(i64)



To



Max



Syntax



Option



Package



Import



Service



Rpc



Stream



Returns



Message



OneOf



Extend



Enum



Reserved



Extensions



Optional



Required



Repeated



Map



String(&'a str)



Ident(&'a str)