pub struct Comment<'a> {
pub type: CommentType,
pub source: Cow<'a, str>,
pub text: Cow<'a, str>,
}Expand description
A parsed comment with both raw source and trimmed text.
Fields
type: CommentTypesource: Cow<'a, str>text: Cow<'a, str>Implementations
Sourceimpl Comment<'_>
impl Comment<'_>
Sourcepub fn into_owned(self) -> Comment<'static>
pub fn into_owned(self) -> Comment<'static>
Copy the structure and clone the original values if it’s not owned.
This is always a deep copy of the structure.
Sourceimpl<'a> Comment<'a>
impl<'a> Comment<'a>
pub fn new(type: CommentType, source: &'a str, text: &'a str) -> Self
pub fn single_line(source: &'a str) -> Self
pub fn multi_line(source: &'a str) -> Self